use serde::{Deserialize, Serialize};
use uuid::Uuid;

#[derive(Debug, Copy, Clone, Deserialize, Serialize)]
pub enum Priority {
    Low,
    Normal,
    High,
}

#[derive(Debug, Copy, Clone, Deserialize, Serialize)]
pub enum Status {
    Todo,
    Doing,
    Done,
}

#[derive(Debug, Deserialize, Serialize)]
pub struct Todo {
    id: Uuid,
    user_id: Uuid,
    title: String,
    description: String,
    priority: Priority,
    status: Status,
}

impl Todo {
    // TODO: Maybe return Result
    pub fn from_json(json: &str) -> Todo {
        log::debug!("Creating Todo from {json}");
        serde_json::from_str::<Todo>(json).expect("Deserialized Todo object")
    }

    pub fn to_json(&self) -> Result<String, serde_json::Error> {
        Ok(serde_json::to_string(self)?)
    }

    pub fn set_user_id(&mut self, user_id: Uuid) {
        self.user_id = user_id
    }
}

#[cfg(test)]
mod tests {
    use super::*;

    #[test]
    fn todo_from_json() {
        let json = "\
{
    \"id\": \"00000000000000000000000000000000\",
    \"user_id\": \"11111111111111111111111111111111\",
    \"title\": \"Test Title\",
    \"description\": \"This is a cool description for my very cool todo!\",
    \"priority\": 1,
    \"status\": 1
}";
        println!("{json}");
        let todo = Todo::from_json(json);
        println!("{todo:?}");
    }
}
