use serde::{Deserialize, Serialize};
use uuid::Uuid;

#[derive(Debug, Deserialize, Serialize)]
pub struct User {
    id: Uuid,
    login: String,
    hash: String,
    salt: String,
}

impl User {
    pub fn new(login: &str, hash: &str, salt: &str) -> User {
        User {
            id: Uuid::new_v4(),
            login: String::from(login),
            hash: String::from(hash),
            salt: String::from(salt),
        }
    }

    // TODO: Maybe return Result
    pub fn from_json(json: &str) -> User {
        log::debug!("Creating User from {json}");
        serde_json::from_str::<User>(json).expect("Deserialized User object")
    }

    pub fn id(&self) -> &Uuid {
        &self.id
    }

    pub fn login(&self) -> &str {
        &self.login
    }

    pub fn hash(&self) -> &str {
        &self.hash
    }

    pub fn salt(&self) -> &str {
        &self.salt
    }
}