/**
 * Author: phga
 * Date: 2022-11-23T23:57
 * Description: This is a rudimentary REST Client created while
 * evaluating different technologies for GLOU
 */

const BACKEND_SERVER_URL = 'localhost:6969';
// Helper function to do the actual fetching from our backend
// For now we always send/receive json -> For a real world example make this more variable
const do_fetch = async (
  method: string,
  path: string,
  payload?: string
): Promise<unknown | string> => {
  try {
    const req = await fetch(`https://${BACKEND_SERVER_URL}${path}`, {
      method,
      credentials: 'include',
      headers: {
        'Access-Control-Allow-Origin': `${BACKEND_SERVER_URL}`,
        'Access-Control-Allow-Credentials': 'true',
        'Content-Type': 'application/json',
        Accept: 'application/json',
      },
      body: payload,
    });

    const res = await req.text();
    return JSON.parse(res);
  } catch (err) {
    console.log(err);
  }
};

const GET = async (path: string): Promise<unknown | string> => {
  return do_fetch('GET', path);
};
const POST = async (path: string, payload?: string): Promise<unknown | string> => {
  return do_fetch('POST', path, payload);
};
const PUT = async (path: string, payload?: string): Promise<unknown | string> => {
  return do_fetch('PUT', path, payload);
};
const DELETE = async (path: string): Promise<unknown | string> => {
  return do_fetch('DELETE', path);
};

// The actual RestClient we will use in our frontend
// It does not support all REST methods for this evaluation
const RestClient = {
  GET,
  POST,
  PUT,
  DELETE,
};

export default RestClient;
